#[non_exhaustive]pub struct CreateRegistryRecordInput {
pub registry_id: Option<String>,
pub name: Option<String>,
pub display_name: Option<String>,
pub description: Option<String>,
pub record_type: Option<RecordType>,
pub descriptors: Option<Descriptors>,
pub record_version: Option<String>,
pub client_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.registry_id: Option<String>The identifier of the registry in which to create the record (ARN or ID)
name: Option<String>The name of the registry record
display_name: Option<String>The human-readable display name of the registry record
description: Option<String>The description of the registry record
record_type: Option<RecordType>The type of the registry record, which determines the descriptor format
descriptors: Option<Descriptors>The typed descriptor content for the registry record
record_version: Option<String>The version of the registry record
client_token: Option<String>Client token for idempotency
Tags to associate with the registry record
Implementations
Sourceimpl CreateRegistryRecordInput
impl CreateRegistryRecordInput
Sourcepub fn registry_id(&self) -> Option<&str>
pub fn registry_id(&self) -> Option<&str>
The identifier of the registry in which to create the record (ARN or ID)
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The human-readable display name of the registry record
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the registry record
Sourcepub fn record_type(&self) -> Option<&RecordType>
pub fn record_type(&self) -> Option<&RecordType>
The type of the registry record, which determines the descriptor format
Sourcepub fn descriptors(&self) -> Option<&Descriptors>
pub fn descriptors(&self) -> Option<&Descriptors>
The typed descriptor content for the registry record
Sourcepub fn record_version(&self) -> Option<&str>
pub fn record_version(&self) -> Option<&str>
The version of the registry record
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Client token for idempotency
Tags to associate with the registry record
Sourceimpl CreateRegistryRecordInput
impl CreateRegistryRecordInput
Sourcepub fn builder() -> CreateRegistryRecordInputBuilder
pub fn builder() -> CreateRegistryRecordInputBuilder
Creates a new builder-style object to manufacture CreateRegistryRecordInput.