#[non_exhaustive]pub struct CreateRegistryRecordOutput {
pub record_arn: String,
pub status: RegistryRecordStatus,
/* private fields */
}Expand description
Response structure for creating a registry record
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.record_arn: StringThe ARN of the created registry record
status: RegistryRecordStatusThe status of the registry record, set to CREATING while the asynchronous workflow is in progress
Implementations
Sourceimpl CreateRegistryRecordOutput
impl CreateRegistryRecordOutput
Sourcepub fn record_arn(&self) -> &str
pub fn record_arn(&self) -> &str
The ARN of the created registry record
Sourcepub fn status(&self) -> &RegistryRecordStatus
pub fn status(&self) -> &RegistryRecordStatus
The status of the registry record, set to CREATING while the asynchronous workflow is in progress
Sourceimpl CreateRegistryRecordOutput
impl CreateRegistryRecordOutput
Sourcepub fn builder() -> CreateRegistryRecordOutputBuilder
pub fn builder() -> CreateRegistryRecordOutputBuilder
Creates a new builder-style object to manufacture CreateRegistryRecordOutput.