#[non_exhaustive]pub struct ApprovalConfigurationBuilder { /* private fields */ }Expand description
A builder for ApprovalConfiguration.
Implementations
Sourceimpl ApprovalConfigurationBuilder
impl ApprovalConfigurationBuilder
Sourcepub fn auto_approval_rules(self, input: AutoApprovalRule) -> Self
pub fn auto_approval_rules(self, input: AutoApprovalRule) -> Self
Appends an item to auto_approval_rules.
To override the contents of this collection use set_auto_approval_rules.
The rules that determine which registry records are automatically approved on submission. When omitted or empty, submitted records require manual review.
Sourcepub fn set_auto_approval_rules(
self,
input: Option<Vec<AutoApprovalRule>>,
) -> Self
pub fn set_auto_approval_rules( self, input: Option<Vec<AutoApprovalRule>>, ) -> Self
The rules that determine which registry records are automatically approved on submission. When omitted or empty, submitted records require manual review.
Sourcepub fn get_auto_approval_rules(&self) -> &Option<Vec<AutoApprovalRule>>
pub fn get_auto_approval_rules(&self) -> &Option<Vec<AutoApprovalRule>>
The rules that determine which registry records are automatically approved on submission. When omitted or empty, submitted records require manual review.
Sourcepub fn build(self) -> ApprovalConfiguration
pub fn build(self) -> ApprovalConfiguration
Consumes the builder and constructs a ApprovalConfiguration.