#[non_exhaustive]pub struct CustomClaimValidationTypeBuilder { /* private fields */ }Expand description
A builder for CustomClaimValidationType.
Implementations
Sourceimpl CustomClaimValidationTypeBuilder
impl CustomClaimValidationTypeBuilder
Sourcepub fn inbound_token_claim_name(self, input: impl Into<String>) -> Self
pub fn inbound_token_claim_name(self, input: impl Into<String>) -> Self
The name of the claim in the inbound token to validate.
This field is required.Sourcepub fn set_inbound_token_claim_name(self, input: Option<String>) -> Self
pub fn set_inbound_token_claim_name(self, input: Option<String>) -> Self
The name of the claim in the inbound token to validate.
Sourcepub fn get_inbound_token_claim_name(&self) -> &Option<String>
pub fn get_inbound_token_claim_name(&self) -> &Option<String>
The name of the claim in the inbound token to validate.
Sourcepub fn inbound_token_claim_value_type(
self,
input: InboundTokenClaimValueType,
) -> Self
pub fn inbound_token_claim_value_type( self, input: InboundTokenClaimValueType, ) -> Self
The value type of the claim in the inbound token, either a string or an array of strings.
This field is required.Sourcepub fn set_inbound_token_claim_value_type(
self,
input: Option<InboundTokenClaimValueType>,
) -> Self
pub fn set_inbound_token_claim_value_type( self, input: Option<InboundTokenClaimValueType>, ) -> Self
The value type of the claim in the inbound token, either a string or an array of strings.
Sourcepub fn get_inbound_token_claim_value_type(
&self,
) -> &Option<InboundTokenClaimValueType>
pub fn get_inbound_token_claim_value_type( &self, ) -> &Option<InboundTokenClaimValueType>
The value type of the claim in the inbound token, either a string or an array of strings.
The value and match operator used to authorize the claim.
This field is required.The value and match operator used to authorize the claim.
The value and match operator used to authorize the claim.
Sourcepub fn build(self) -> Result<CustomClaimValidationType, BuildError>
pub fn build(self) -> Result<CustomClaimValidationType, BuildError>
Consumes the builder and constructs a CustomClaimValidationType.
This method will fail if any of the following fields are not set: