#[non_exhaustive]pub struct ManagedVpcResourceBuilder { /* private fields */ }Expand description
A builder for ManagedVpcResource.
Implementations
Sourceimpl ManagedVpcResourceBuilder
impl ManagedVpcResourceBuilder
Sourcepub fn vpc_identifier(self, input: impl Into<String>) -> Self
pub fn vpc_identifier(self, input: impl Into<String>) -> Self
The identifier of the VPC in which the private endpoint is provisioned.
This field is required.Sourcepub fn set_vpc_identifier(self, input: Option<String>) -> Self
pub fn set_vpc_identifier(self, input: Option<String>) -> Self
The identifier of the VPC in which the private endpoint is provisioned.
Sourcepub fn get_vpc_identifier(&self) -> &Option<String>
pub fn get_vpc_identifier(&self) -> &Option<String>
The identifier of the VPC in which the private endpoint is provisioned.
Sourcepub fn subnet_ids(self, input: impl Into<String>) -> Self
pub fn subnet_ids(self, input: impl Into<String>) -> Self
Appends an item to subnet_ids.
To override the contents of this collection use set_subnet_ids.
The identifiers of the subnets in which the private endpoint network interfaces are placed.
Sourcepub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
The identifiers of the subnets in which the private endpoint network interfaces are placed.
Sourcepub fn get_subnet_ids(&self) -> &Option<Vec<String>>
pub fn get_subnet_ids(&self) -> &Option<Vec<String>>
The identifiers of the subnets in which the private endpoint network interfaces are placed.
Sourcepub fn endpoint_ip_address_type(self, input: EndpointIpAddressType) -> Self
pub fn endpoint_ip_address_type(self, input: EndpointIpAddressType) -> Self
The IP address type used by the private endpoint, either IPV4 or IPV6.
This field is required.Sourcepub fn set_endpoint_ip_address_type(
self,
input: Option<EndpointIpAddressType>,
) -> Self
pub fn set_endpoint_ip_address_type( self, input: Option<EndpointIpAddressType>, ) -> Self
The IP address type used by the private endpoint, either IPV4 or IPV6.
Sourcepub fn get_endpoint_ip_address_type(&self) -> &Option<EndpointIpAddressType>
pub fn get_endpoint_ip_address_type(&self) -> &Option<EndpointIpAddressType>
The IP address type used by the private endpoint, either IPV4 or IPV6.
Sourcepub fn security_group_ids(self, input: impl Into<String>) -> Self
pub fn security_group_ids(self, input: impl Into<String>) -> Self
Appends an item to security_group_ids.
To override the contents of this collection use set_security_group_ids.
The identifiers of the security groups associated with the private endpoint network interfaces.
Sourcepub fn set_security_group_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_security_group_ids(self, input: Option<Vec<String>>) -> Self
The identifiers of the security groups associated with the private endpoint network interfaces.
Sourcepub fn get_security_group_ids(&self) -> &Option<Vec<String>>
pub fn get_security_group_ids(&self) -> &Option<Vec<String>>
The identifiers of the security groups associated with the private endpoint network interfaces.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
A map of tag keys to tag values.
A map of tag keys to tag values.
A map of tag keys to tag values.
Sourcepub fn routing_domain(self, input: impl Into<String>) -> Self
pub fn routing_domain(self, input: impl Into<String>) -> Self
The routing domain used to resolve traffic through the private endpoint.
Sourcepub fn set_routing_domain(self, input: Option<String>) -> Self
pub fn set_routing_domain(self, input: Option<String>) -> Self
The routing domain used to resolve traffic through the private endpoint.
Sourcepub fn get_routing_domain(&self) -> &Option<String>
pub fn get_routing_domain(&self) -> &Option<String>
The routing domain used to resolve traffic through the private endpoint.
Sourcepub fn build(self) -> Result<ManagedVpcResource, BuildError>
pub fn build(self) -> Result<ManagedVpcResource, BuildError>
Consumes the builder and constructs a ManagedVpcResource.
This method will fail if any of the following fields are not set: