#[non_exhaustive]pub struct A2aAgentCardDescriptor {
pub data: Option<String>,
pub data_schema_version: Option<String>,
pub source: Option<DescriptorSource>,
}Expand description
Descriptor that defines the content of an A2A (Agent-to-Agent) agent card registry record. The content is validated against the A2A protocol schema.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: Option<String>The A2A agent card content, serialized as descriptor payload data.
data_schema_version: Option<String>The schema version of the descriptor payload.
source: Option<DescriptorSource>The optional source configuration used to synchronize the A2A agent card descriptor content.
Implementations
Sourceimpl A2aAgentCardDescriptor
impl A2aAgentCardDescriptor
Sourcepub fn data(&self) -> Option<&str>
pub fn data(&self) -> Option<&str>
The A2A agent card content, serialized as descriptor payload data.
Sourcepub fn data_schema_version(&self) -> Option<&str>
pub fn data_schema_version(&self) -> Option<&str>
The schema version of the descriptor payload.
Sourcepub fn source(&self) -> Option<&DescriptorSource>
pub fn source(&self) -> Option<&DescriptorSource>
The optional source configuration used to synchronize the A2A agent card descriptor content.
Sourceimpl A2aAgentCardDescriptor
impl A2aAgentCardDescriptor
Sourcepub fn builder() -> A2aAgentCardDescriptorBuilder
pub fn builder() -> A2aAgentCardDescriptorBuilder
Creates a new builder-style object to manufacture A2aAgentCardDescriptor.