#[non_exhaustive]pub struct AgentSkillsDefinitionDescriptor {
pub data: Option<String>,
pub data_schema_version: Option<String>,
pub additional_data: Option<AgentSkillsAdditionalData>,
}Expand description
Descriptor that defines an agent skills registry record and its associated content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: Option<String>The agent skills definition content, serialized as descriptor payload data.
data_schema_version: Option<String>The schema version of the descriptor payload.
additional_data: Option<AgentSkillsAdditionalData>Additional data associated with the agent skills definition descriptor.
Implementations
Sourceimpl AgentSkillsDefinitionDescriptor
impl AgentSkillsDefinitionDescriptor
Sourcepub fn data(&self) -> Option<&str>
pub fn data(&self) -> Option<&str>
The agent skills definition content, serialized as descriptor payload data.
Sourcepub fn data_schema_version(&self) -> Option<&str>
pub fn data_schema_version(&self) -> Option<&str>
The schema version of the descriptor payload.
Sourcepub fn additional_data(&self) -> Option<&AgentSkillsAdditionalData>
pub fn additional_data(&self) -> Option<&AgentSkillsAdditionalData>
Additional data associated with the agent skills definition descriptor.
Sourceimpl AgentSkillsDefinitionDescriptor
impl AgentSkillsDefinitionDescriptor
Sourcepub fn builder() -> AgentSkillsDefinitionDescriptorBuilder
pub fn builder() -> AgentSkillsDefinitionDescriptorBuilder
Creates a new builder-style object to manufacture AgentSkillsDefinitionDescriptor.