#[non_exhaustive]pub struct ApprovalConfiguration {
pub auto_approval_rules: Option<Vec<AutoApprovalRule>>,
}Expand description
Configuration for the registry's record approval workflow. Controls whether records submitted for approval require manual review before they become approved and discoverable, or are auto-approved. When no auto-approval rules are configured, submitted records require manual review.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.auto_approval_rules: Option<Vec<AutoApprovalRule>>The rules that determine which registry records are automatically approved on submission. When omitted or empty, submitted records require manual review.
Implementations
Sourceimpl ApprovalConfiguration
impl ApprovalConfiguration
Sourcepub fn auto_approval_rules(&self) -> &[AutoApprovalRule]
pub fn auto_approval_rules(&self) -> &[AutoApprovalRule]
The rules that determine which registry records are automatically approved on submission. When omitted or empty, submitted records require manual review.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .auto_approval_rules.is_none().
Sourceimpl ApprovalConfiguration
impl ApprovalConfiguration
Sourcepub fn builder() -> ApprovalConfigurationBuilder
pub fn builder() -> ApprovalConfigurationBuilder
Creates a new builder-style object to manufacture ApprovalConfiguration.