#[non_exhaustive]pub struct AuthorizingClaimMatchValueType {
pub claim_match_value: Option<ClaimMatchValueType>,
pub claim_match_operator: ClaimMatchOperatorType,
}Expand description
The value and match operator used to authorize a claim during JWT validation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.claim_match_value: Option<ClaimMatchValueType>The expected value or values that the claim is compared against.
claim_match_operator: ClaimMatchOperatorTypeThe operator used to compare the claim value against the expected value.
Implementations
Sourceimpl AuthorizingClaimMatchValueType
impl AuthorizingClaimMatchValueType
Sourcepub fn claim_match_value(&self) -> Option<&ClaimMatchValueType>
pub fn claim_match_value(&self) -> Option<&ClaimMatchValueType>
The expected value or values that the claim is compared against.
Sourcepub fn claim_match_operator(&self) -> &ClaimMatchOperatorType
pub fn claim_match_operator(&self) -> &ClaimMatchOperatorType
The operator used to compare the claim value against the expected value.
Sourceimpl AuthorizingClaimMatchValueType
impl AuthorizingClaimMatchValueType
Sourcepub fn builder() -> AuthorizingClaimMatchValueTypeBuilder
pub fn builder() -> AuthorizingClaimMatchValueTypeBuilder
Creates a new builder-style object to manufacture AuthorizingClaimMatchValueType.