#[non_exhaustive]pub struct CustomClaimValidationType {
pub inbound_token_claim_name: String,
pub inbound_token_claim_value_type: InboundTokenClaimValueType,
pub authorizing_claim_match_value: Option<AuthorizingClaimMatchValueType>,
}Expand description
A validation rule applied to a single claim of an inbound JWT.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inbound_token_claim_name: StringThe name of the claim in the inbound token to validate.
inbound_token_claim_value_type: InboundTokenClaimValueTypeThe value type of the claim in the inbound token, either a string or an array of strings.
The value and match operator used to authorize the claim.
Implementations
Sourceimpl CustomClaimValidationType
impl CustomClaimValidationType
Sourcepub fn inbound_token_claim_name(&self) -> &str
pub fn inbound_token_claim_name(&self) -> &str
The name of the claim in the inbound token to validate.
Sourcepub fn inbound_token_claim_value_type(&self) -> &InboundTokenClaimValueType
pub fn inbound_token_claim_value_type(&self) -> &InboundTokenClaimValueType
The value type of the claim in the inbound token, either a string or an array of strings.
The value and match operator used to authorize the claim.
Sourceimpl CustomClaimValidationType
impl CustomClaimValidationType
Sourcepub fn builder() -> CustomClaimValidationTypeBuilder
pub fn builder() -> CustomClaimValidationTypeBuilder
Creates a new builder-style object to manufacture CustomClaimValidationType.