#[non_exhaustive]pub struct DescriptorSourceFromUrl {
pub url: String,
pub credential_provider_configurations: Option<Vec<RegistryRecordCredentialProviderConfiguration>>,
}Expand description
URL-based descriptor source configuration, with credential provider configurations for authenticated URL retrieval.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringThe URL from which the descriptor content is retrieved.
credential_provider_configurations: Option<Vec<RegistryRecordCredentialProviderConfiguration>>The credential providers used to authenticate when fetching descriptor content from the source URL.
Implementations
Sourceimpl DescriptorSourceFromUrl
impl DescriptorSourceFromUrl
Sourcepub fn credential_provider_configurations(
&self,
) -> &[RegistryRecordCredentialProviderConfiguration]
pub fn credential_provider_configurations( &self, ) -> &[RegistryRecordCredentialProviderConfiguration]
The credential providers used to authenticate when fetching descriptor content from the source URL.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .credential_provider_configurations.is_none().
Sourceimpl DescriptorSourceFromUrl
impl DescriptorSourceFromUrl
Sourcepub fn builder() -> DescriptorSourceFromUrlBuilder
pub fn builder() -> DescriptorSourceFromUrlBuilder
Creates a new builder-style object to manufacture DescriptorSourceFromUrl.