#[non_exhaustive]pub struct Descriptors {
pub mcp_server: Option<McpServerDescriptor>,
pub a2a_agent_card: Option<A2aAgentCardDescriptor>,
pub agent_skills_definition: Option<AgentSkillsDefinitionDescriptor>,
pub custom: Option<CustomDescriptor>,
}Expand description
The typed set of descriptors for a registry record. Exactly one descriptor field is populated based on the record type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mcp_server: Option<McpServerDescriptor>The MCP server descriptor, populated when the record type is MCP.
a2a_agent_card: Option<A2aAgentCardDescriptor>The A2A agent card descriptor, populated when the record type is AGENT.
agent_skills_definition: Option<AgentSkillsDefinitionDescriptor>The agent skills definition descriptor, populated when the record type is SKILL.
custom: Option<CustomDescriptor>The custom descriptor, populated when the record type is CUSTOM.
Implementations
Sourceimpl Descriptors
impl Descriptors
Sourcepub fn mcp_server(&self) -> Option<&McpServerDescriptor>
pub fn mcp_server(&self) -> Option<&McpServerDescriptor>
The MCP server descriptor, populated when the record type is MCP.
Sourcepub fn a2a_agent_card(&self) -> Option<&A2aAgentCardDescriptor>
pub fn a2a_agent_card(&self) -> Option<&A2aAgentCardDescriptor>
The A2A agent card descriptor, populated when the record type is AGENT.
Sourcepub fn agent_skills_definition(
&self,
) -> Option<&AgentSkillsDefinitionDescriptor>
pub fn agent_skills_definition( &self, ) -> Option<&AgentSkillsDefinitionDescriptor>
The agent skills definition descriptor, populated when the record type is SKILL.
Sourcepub fn custom(&self) -> Option<&CustomDescriptor>
pub fn custom(&self) -> Option<&CustomDescriptor>
The custom descriptor, populated when the record type is CUSTOM.
Sourceimpl Descriptors
impl Descriptors
Sourcepub fn builder() -> DescriptorsBuilder
pub fn builder() -> DescriptorsBuilder
Creates a new builder-style object to manufacture Descriptors.