#[non_exhaustive]pub struct DiscoveryConfiguration {
pub authorizer_configuration: Option<AuthorizerConfiguration>,
pub authorizer_type: Option<RegistryAuthorizerType>,
}Expand description
Discovery configuration for the registry. Controls how consumers are authorized to search the registry and invoke its MCP endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.The authorizer configuration for the registry. Required when authorizerType is CUSTOM_JWT.
The type of authorizer that controls how consumers access the registry's search and MCP invoke operations.
Implementations
Sourceimpl DiscoveryConfiguration
impl DiscoveryConfiguration
The authorizer configuration for the registry. Required when authorizerType is CUSTOM_JWT.
The type of authorizer that controls how consumers access the registry's search and MCP invoke operations.
Sourceimpl DiscoveryConfiguration
impl DiscoveryConfiguration
Sourcepub fn builder() -> DiscoveryConfigurationBuilder
pub fn builder() -> DiscoveryConfigurationBuilder
Creates a new builder-style object to manufacture DiscoveryConfiguration.