#[non_exhaustive]pub struct McpServerDescriptor {
pub data: Option<String>,
pub data_schema_version: Option<String>,
pub additional_data: Option<McpServerAdditionalData>,
pub source: Option<DescriptorSource>,
}Expand description
Descriptor that defines the content of an MCP (Model Context Protocol) server registry record, including the server definition and its tool definitions. The content is validated against the MCP protocol schema.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: Option<String>The MCP server descriptor content, serialized as descriptor payload data.
data_schema_version: Option<String>The schema version of the descriptor payload.
additional_data: Option<McpServerAdditionalData>Additional data associated with the MCP server descriptor, such as tool definitions.
source: Option<DescriptorSource>The optional source configuration used to synchronize the MCP server descriptor content.
Implementations
Sourceimpl McpServerDescriptor
impl McpServerDescriptor
Sourcepub fn data(&self) -> Option<&str>
pub fn data(&self) -> Option<&str>
The MCP server descriptor content, serialized as descriptor payload data.
Sourcepub fn data_schema_version(&self) -> Option<&str>
pub fn data_schema_version(&self) -> Option<&str>
The schema version of the descriptor payload.
Sourcepub fn additional_data(&self) -> Option<&McpServerAdditionalData>
pub fn additional_data(&self) -> Option<&McpServerAdditionalData>
Additional data associated with the MCP server descriptor, such as tool definitions.
Sourcepub fn source(&self) -> Option<&DescriptorSource>
pub fn source(&self) -> Option<&DescriptorSource>
The optional source configuration used to synchronize the MCP server descriptor content.
Sourceimpl McpServerDescriptor
impl McpServerDescriptor
Sourcepub fn builder() -> McpServerDescriptorBuilder
pub fn builder() -> McpServerDescriptorBuilder
Creates a new builder-style object to manufacture McpServerDescriptor.