#[non_exhaustive]pub struct RegistrySummary {
pub name: String,
pub description: Option<String>,
pub registry_id: String,
pub registry_arn: String,
pub discovery_configuration: Option<DiscoveryConfiguration>,
pub status: RegistryStatus,
pub status_reason: Option<String>,
pub created_at: DateTime,
pub updated_at: DateTime,
}Expand description
Registry summary for list operations
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRegistry name
description: Option<String>Registry description
registry_id: StringUnique registry identifier
registry_arn: StringRegistry Amazon Resource Name
discovery_configuration: Option<DiscoveryConfiguration>Discovery configuration for the registry
status: RegistryStatusCurrent status of the registry
status_reason: Option<String>The reason for the current status. Typically populated when the status indicates a failure state.
created_at: DateTimeThe timestamp when the registry was created
updated_at: DateTimeThe timestamp when the registry was last updated
Implementations
Sourceimpl RegistrySummary
impl RegistrySummary
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Registry description
Sourcepub fn registry_id(&self) -> &str
pub fn registry_id(&self) -> &str
Unique registry identifier
Sourcepub fn registry_arn(&self) -> &str
pub fn registry_arn(&self) -> &str
Registry Amazon Resource Name
Sourcepub fn discovery_configuration(&self) -> Option<&DiscoveryConfiguration>
pub fn discovery_configuration(&self) -> Option<&DiscoveryConfiguration>
Discovery configuration for the registry
Sourcepub fn status(&self) -> &RegistryStatus
pub fn status(&self) -> &RegistryStatus
Current status of the registry
Sourcepub fn status_reason(&self) -> Option<&str>
pub fn status_reason(&self) -> Option<&str>
The reason for the current status. Typically populated when the status indicates a failure state.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The timestamp when the registry was created
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
The timestamp when the registry was last updated
Sourceimpl RegistrySummary
impl RegistrySummary
Sourcepub fn builder() -> RegistrySummaryBuilder
pub fn builder() -> RegistrySummaryBuilder
Creates a new builder-style object to manufacture RegistrySummary.