#[non_exhaustive]pub struct UpdatedAgentSkillsAdditionalDataFields {
pub skill_md: Option<UpdatedAgentSkillsMdDescriptor>,
}Expand description
The set of agent skills additional-data fields that can be individually updated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.skill_md: Option<UpdatedAgentSkillsMdDescriptor>The patch for the agent skills markdown descriptor field.
Implementations
Sourceimpl UpdatedAgentSkillsAdditionalDataFields
impl UpdatedAgentSkillsAdditionalDataFields
Sourcepub fn skill_md(&self) -> Option<&UpdatedAgentSkillsMdDescriptor>
pub fn skill_md(&self) -> Option<&UpdatedAgentSkillsMdDescriptor>
The patch for the agent skills markdown descriptor field.
Sourceimpl UpdatedAgentSkillsAdditionalDataFields
impl UpdatedAgentSkillsAdditionalDataFields
Sourcepub fn builder() -> UpdatedAgentSkillsAdditionalDataFieldsBuilder
pub fn builder() -> UpdatedAgentSkillsAdditionalDataFieldsBuilder
Creates a new builder-style object to manufacture UpdatedAgentSkillsAdditionalDataFields.